﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Drawing;
using Infragistics.Win;
using Infragistics.Win.UltraWinEditors;

namespace Infragistics.Sample.CustomControls
{
    public class ToggleCheckEditor : UltraCheckEditor
    {
        #region Members

        private const int FrameMiddle = 18;
        private const int FrameStart = 0;
        private bool initialState;

        #endregion //Members

        #region Constructor

        public ToggleCheckEditor() : base()
        {
            this.Style = EditCheckStyle.Button;
            this.ButtonStyle = UIElementButtonStyle.Borderless;
            this.UseOsThemes = DefaultableBoolean.False;
        }

        #endregion //Constructor

        #region OnHandleCreated

        /// <summary>
        /// Invoked when the handle of the control is created.
        /// </summary>
        /// <param name="e">Event arguments</param>
        protected override void OnHandleCreated(EventArgs e)
        {
            base.OnHandleCreated(e);

            bool isChecked = this.Checked;
            Image image = (isChecked) ? 
                ToggleSwitchAnimatedGIFSample.Properties.Resources.On: 
                ToggleSwitchAnimatedGIFSample.Properties.Resources.Off;
            this.initialState = isChecked;

            this.Appearance.ImageBackground = image;
            AnimatedImageManager.SuspendAnimation(image);
            image.Tag = FrameStart;

            AnimatedImageManager.ImageFrameChanged += (sender, args) =>
                {
                    if (args.Image != this.Appearance.ImageBackground)
                        return;

                    if (args.Image.Tag is int)
                    {
                        if (args.CurrentFrame == (int)args.Image.Tag)
                            args.SuspendAnimation = true;
                    }
                };
        }

        #endregion //OnHandleCreated

        #region OnCheckedChanged

        /// <summary>
        /// This is called after the Checked property is changed
        /// </summary>
        protected override void OnCheckedChanged()
        {
            base.OnCheckedChanged();

            Image image = this.Appearance.ImageBackground;
            if (image != null)
            {
                image.Tag = (this.Checked != this.initialState) ? FrameMiddle : FrameStart;
                if (AnimatedImageManager.IsImageAnimationSuspended(image))
                    AnimatedImageManager.ResumeAnimation(image);
            }
        }

        #endregion //OnCheckedChanged

    }
}
